@@ -98,8 +98,12 @@ class JunOSDriver:
         """Open the connection with the device."""
         try:
             self.device.open(auto_probe=self.auto_probe)
-        except (ConnectTimeoutError, ProbeError) as cte:
-            raise Exception(cte.msg)
+        except ProbeError:
+            raise Exception('connection probe error')
+        except ConnectTimeoutError:
+            raise Exception('connection timeout error')
+
+
         self.device.timeout = self.timeout
         self.device._conn._session.transport.set_keepalive(self.keepalive)
         if hasattr(self.device, "cu"):
@@ -107,8 +111,6 @@ class JunOSDriver:
             # ValueError: requested attribute name cu already exists
             del self.device.cu
         self.device.bind(cu=Config)
-        if not self.lock_disable and self.session_config_lock:
-            self._lock()
 
     def close(self):
         """Close the connection."""
